using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.SceneManagement;
using UnityEngine.UI;

public class StateController : MonoBehaviour {

    [Header("Respawning")]
    [SerializeField] GameObject player;
    public GameObject spawnPoint;
    [SerializeField] private GameObject deathCanvas;

    [Header("Pause Menu")]
    public bool isPaused = false;
    public GameObject pauseMenuCanvas;

    void Awake() {
        DontDestroyOnLoad(this.gameObject);
        SceneManager.sceneLoaded += OnSceneLoaded;
    }

    void OnSceneLoaded(Scene scene, LoadSceneMode mode) { 
        deathCanvas = GameObject.Find("DeathUICanvas");
        if (deathCanvas != null) {
            Button respawnButton = GameObject.Find("RespawnButton").GetComponent<Button>();
            respawnButton.onClick.AddListener(RespawnPlayer);
            deathCanvas.SetActive(false);
        }

        pauseMenuCanvas = GameObject.Find("PauseMenuCanvas");
        if (pauseMenuCanvas != null) {
            TogglePauseMenu(false);
        }

    }

    void OnPause() {
        if (!isPaused) {
            Time.timeScale = 0;
            TogglePauseMenu(true);
        } else {
            Time.timeScale = 1;
            TogglePauseMenu(false);
        }
        isPaused = !isPaused;
    }

    void TogglePauseMenu(bool showPauseMenu) {
        pauseMenuCanvas.SetActive(showPauseMenu);
    }

    public void RespawnPlayer() {
        SetDeathCanvasActive(false);
        GameObject.Find("Main Camera").GetComponent<CameraMovement>().FindPlayer();
        Instantiate(player, spawnPoint.transform.position, player.transform.rotation);
    }

    public void SetDeathCanvasActive(bool activeState) {
        deathCanvas.SetActive(activeState);
    }
}
